@@ -54,9 +54,7 @@ kpToolSelectionMoveCommand::kpToolSelectionMoveCommand (const QString &name,
     m_startPoint = m_endPoint = doc->selection ()->topLeft ();
 }
 
-kpToolSelectionMoveCommand::~kpToolSelectionMoveCommand ()
-{
-}
+kpToolSelectionMoveCommand::~kpToolSelectionMoveCommand () = default;
 
 
 // public
@@ -100,7 +98,7 @@ void kpToolSelectionMoveCommand::execute ()
 
     vm->setQueueUpdates ();
     {
-        foreach (const QPoint &p, m_copyOntoDocumentPoints)
+        for (const auto &p : m_copyOntoDocumentPoints)
         {
             sel->moveTo (p);
             doc->selectionCopyOntoDocument ();
@@ -132,8 +130,10 @@ void kpToolSelectionMoveCommand::unexecute ()
 
     vm->setQueueUpdates ();
 
-    if (!m_oldDocumentImage.isNull ())
+    if (!m_oldDocumentImage.isNull ()) {
         doc->setImageAt (m_oldDocumentImage, m_documentBoundingRect.topLeft ());
+    }
+
 #if DEBUG_KP_TOOL_SELECTION && 1
     qCDebug(kpLogCommands) << "\tmove to startPoint=" << m_startPoint;
 #endif
@@ -149,8 +149,7 @@ void kpToolSelectionMoveCommand::moveTo (const QPoint &point, bool moveLater)
 {
 #if DEBUG_KP_TOOL_SELECTION && 0
     qCDebug(kpLogCommands) << "kpToolSelectionMoveCommand::moveTo" << point
-               << " moveLater=" << moveLater
-               <<endl;
+               << " moveLater=" << moveLater;
 #endif
 
     if (!moveLater)
@@ -162,8 +161,9 @@ void kpToolSelectionMoveCommand::moveTo (const QPoint &point, bool moveLater)
         // Must have content before it can be moved.
         Q_ASSERT (sel && sel->hasContent ());
 
-        if (point == sel->topLeft ())
+        if (point == sel->topLeft ()) {
             return;
+        }
 
         sel->moveTo (point);
     }
@@ -192,8 +192,9 @@ void kpToolSelectionMoveCommand::copyOntoDocument ()
     // to be consistent with the requirement on other selection operations.
     Q_ASSERT (sel && sel->hasContent ());
 
-    if (m_oldDocumentImage.isNull ())
+    if (m_oldDocumentImage.isNull ()) {
         m_oldDocumentImage = doc->image ();
+    }
 
     QRect selBoundingRect = sel->boundingRect ();
     m_documentBoundingRect = m_documentBoundingRect.united (selBoundingRect);
