@@ -33,12 +33,12 @@
 #include "layers/selections/text/kpTextSelection.h"
 #include "views/manager/kpViewManager.h"
 
-#include <qlist.h>
+#include <QList>
 
 //---------------------------------------------------------------------
 
 kpToolTextInsertCommand::kpToolTextInsertCommand (const QString &name,
-        int row, int col, QString newText,
+        int row, int col, const QString& newText,
         kpCommandEnvironment *environ)
     : kpNamedCommand (name, environ),
       m_row (row), m_col (col)
@@ -52,8 +52,9 @@ kpToolTextInsertCommand::kpToolTextInsertCommand (const QString &name,
 // public
 void kpToolTextInsertCommand::addText (const QString &moreText)
 {
-    if (moreText.isEmpty ())
+    if (moreText.isEmpty ()) {
         return;
+    }
 
     QList <QString> textLines = textSelection ()->textLines ();
     const QString leftHalf = textLines [m_row].left (m_col);
@@ -72,7 +73,8 @@ void kpToolTextInsertCommand::addText (const QString &moreText)
 // public virtual [base kpCommand]
 kpCommandSize::SizeType kpToolTextInsertCommand::size () const
 {
-    return (kpCommandSize::SizeType) m_newText.length () * sizeof (QChar);
+    return static_cast<kpCommandSize::SizeType>
+            (static_cast<unsigned int> (m_newText.length ()) * sizeof (QChar));
 }
 
 //---------------------------------------------------------------------
