@@ -110,7 +110,7 @@ QImage kpDocument::getPixmapFromFile(const QUrl &url, bool suppressDoesntExistDi
             //       Or at least choose one consistently.
             //
             // TODO: Have captions for all dialogs in KolourPaint.
-            KMessageBox::sorry (parent,
+            KMessageBox::error (parent,
                                 i18n ("Could not open \"%1\".",
                                       kpUrlFormatter::PrettyFilename (url)));
         }
@@ -137,11 +137,16 @@ QImage kpDocument::getPixmapFromFile(const QUrl &url, bool suppressDoesntExistDi
     reader.setAutoTransform(true);
     reader.setDecideFormatFromContent(true);
 
-    QImage image = reader.read();
+    // Do *NOT* convert to
+    // QImage image = reader.read();
+    // this variant is more lenient on errors and we may get something that we would not otherwise
+    // e.g. image from https://bugs.kde.org/show_bug.cgi?id=441554
+    QImage image;
+    reader.read(&image);
 
     if (image.isNull ())
     {
-        KMessageBox::sorry (parent,
+        KMessageBox::error (parent,
                             i18n ("Could not open \"%1\" - unsupported image format.\n"
                                   "The file may be corrupt.",
                                   kpUrlFormatter::PrettyFilename (url)));
