@@ -50,12 +50,13 @@ class QMouseEvent;
 class QImage;
 class QWheelEvent;
 
+class KToggleAction;
+
 class kpColor;
 class kpCommandHistory;
 class kpDocument;
 class kpView;
 class kpViewManager;
-class kpToolAction;
 class kpToolEnvironment;
 class kpToolToolBar;
 
@@ -83,13 +84,10 @@ public:
             QObject *parent, const QString &name);
     ~kpTool () override;
 
-    kpToolAction *action () const;
+    KToggleAction *action () const;
 
     QString text () const;
 
-    static QString toolTipForTextAndShortcut (const QString &text, const QList<QKeySequence> &shortcut);
-    QString toolTip () const;
-
     // Given a single <key>, returns a shortcut with <key>
     // (disabled when the user is editing text) and as an alternate,
     // <some modifiers>+<key>.
@@ -121,9 +119,6 @@ private:
     // Only called by ctor to create action().
     void initAction ();
 
-signals:
-    void actionToolTipChanged();
-
 public slots:
     // Call this when something below the mouse cursor may have changed
     // and/or if the view has moved relative to the cursor (as opposed to
