@@ -41,10 +41,10 @@ public:
     kpToolLine (kpToolEnvironment *environ, QObject *parent);
 
 private:
-    QString haventBegunShapeUserMessage () const Q_DECL_OVERRIDE;
+    QString haventBegunShapeUserMessage () const override;
 
 public:
-    void endDraw (const QPoint &, const QRect &) Q_DECL_OVERRIDE;
+    void endDraw (const QPoint &, const QRect &) override;
 };
 
 
