@@ -338,9 +338,8 @@ void kpView::paintEventDrawSelectionResizeHandles (const QRect &clipRect)
     painter.setPen(Qt::black);
     painter.setBrush(Qt::cyan);
 
-    for (const auto &r : selResizeHandlesRegion.rects()) {
+    for (const QRect &r : selResizeHandlesRegion)
       painter.drawRect(r);
-    }
 }
 
 //---------------------------------------------------------------------
@@ -584,11 +583,7 @@ void kpView::paintEvent (QPaintEvent *e)
 
     // It seems that e->region() is already clipped by Qt to the visible
     // part of the view (which could be quite small inside a scrollview).
-    const auto& viewRegion = e->region ();
-    QVector <QRect> rects = viewRegion.rects ();
-#if DEBUG_KP_VIEW_RENDERER
-    qCDebug(kpLogViews) << "\t#rects = " << rects.count ();
-#endif
+    const QRegion viewRegion = e->region ();
 
     // Draw all of the requested regions of the document _before_ drawing
     // the grid lines, buddy rectangle and selection resize handles.
@@ -602,10 +597,8 @@ void kpView::paintEvent (QPaintEvent *e)
     // parts of nearby grid lines (which were drawn in a previous iteration)
     // with document pixels.  Those grid line parts are probably not going to
     // be redrawn, so will appear to be missing.
-    for (const auto &r : rects)
-    {
-        paintEventDrawDoc_Unclipped (r);
-    }
+    for (const QRect &r : viewRegion)
+      paintEventDrawDoc_Unclipped (r);
 
     //
     // Draw Grid Lines
@@ -614,7 +607,7 @@ void kpView::paintEvent (QPaintEvent *e)
     if ( isGridShown() )
     {
       QPainter painter(this);
-      for (const auto &r : rects)
+      for (const QRect &r : viewRegion)
         paintEventDrawGridLines(&painter, r);
     }
 
