@@ -30,12 +30,12 @@
 #define KP_TOOL_WIDGET_BASE_H
 
 
-#include <qframe.h>
-#include <qpair.h>
-#include <qpixmap.h>
-#include <qrect.h>
-#include <qlist.h>
-#include <qwidget.h>
+#include <QFrame>
+#include <QPair>
+#include <QPixmap>
+#include <QRect>
+#include <QList>
+#include <QWidget>
 
 
 class QMouseEvent;
@@ -50,7 +50,7 @@ Q_OBJECT
 public:
     // (must provide a <name> for config to work)
     kpToolWidgetBase (QWidget *parent, const QString &name);
-    virtual ~kpToolWidgetBase ();
+    ~kpToolWidgetBase () override;
 
 public:
     void addOption (const QPixmap &pixmap, const QString &toolTip = QString());
@@ -80,8 +80,8 @@ public:
 
     int selected () const;
 
-    bool hasPreviousOption (int *row = 0, int *col = 0) const;
-    bool hasNextOption (int *row = 0, int *col = 0) const;
+    bool hasPreviousOption (int *row = nullptr, int *col = nullptr) const;
+    bool hasNextOption (int *row = nullptr, int *col = nullptr) const;
 
 public slots:
     // (returns whether <row> and <col> were in range)
@@ -95,10 +95,10 @@ signals:
     void optionSelected (int row, int col);
 
 protected:
-    virtual bool event (QEvent *e);
+    bool event (QEvent *e) override;
  
-    virtual void mousePressEvent (QMouseEvent *e);
-    virtual void paintEvent (QPaintEvent *e);
+    void mousePressEvent (QMouseEvent *e) override;
+    void paintEvent (QPaintEvent *e) override;
 
     QWidget *m_baseWidget;
 
